battery_monitor library                         {#mainpage}
============

## Description

C++ driver to monitor the paylaod battery for the Tibi, Dabo and Teo platforms.

## Installation

* Add the labrobotica repository if it is not already added:

Run the commands on _add repository_ and _add key_ from [labrobotica_how_to installation](https://gitlab.iri.upc.edu/labrobotica/labrobotica_how_to/-/blob/master/README.md#installation)

* Install the package:

``` sudo apt update && sudo apt install iri-battery-monitor-dev ```

## Important information

To use this driver is necessary to unload the *ftdi_sio* module, so the device is detected as a serial-usb device.
This can be achieved with the following command
   
   ```sudo rmmod ftdi_sio```
    
or executing the following script:

   ```unbind_ftdi_udev.sh -s <serial_number>```

## Disclaimer  

Copyright (C) 20017-2019 Institut de Robòtica i Informàtica Industrial, CSIC-UPC.

Mantainer: IRI labrobotica (labrobotica@iri.upc.edu)

Author: shernand (shernand@iri.upc.edu)

All rights reserved.

This file is part of battery_monitor driver library
battery_monitor driver library is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License, or
at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>

## For developers

<details><summary>click here</summary>
<p>

## Dependencies

This package requires of the following system libraries and packages

 * [cmake](https://www.cmake.org "CMake's Homepage"), a cross-platform build system.
 * [doxygen](http://www.doxygen.org "Doxygen's Homepage") and [graphviz](http://www.graphviz.org "Graphviz's Homepage") to generate the documentation.
 * stdc++.

Under linux all of these utilities are available in ready-to-use packages.

This package also requires of the following IRI libraries:

 * [iriutils](https://gitlab.iri.upc.edu/labrobotica/algorithms/iriutils "iriutils gitlab page"), a set of basic tools.
 * [comm](https://gitlab.iri.upc.edu/labrobotica/drivers/comm "comm gitlab page"), a set of drivers for standard communication devices.
 * [dynamixel](https://gitlab.iri.upc.edu/labrobotica/drivers/dynamixel "dynamixel gitlab page"), a driver for dynamixel communication protocol.
 
This package also contains the following packages as Git Submodules:

 * [avr8_smbus_battery_monitor](https://gitlab.iri.upc.edu/labrobotica/firmware/avr8_smbus_battery_monitor), a firmware to read battery information through SMBUS

## Compilation and installation

Download this repository and create a build folder inside:

``` mkdir build ```

Inside the build folder execute the following commands:

``` cmake .. ```

The default build mode is DEBUG. That is, objects and executables include debug information.

The RELEASE build mode optimizes for speed. To build in this mode execute instead

``` cmake .. -DCMAKE_BUILD_TYPE=RELEASE ```

The release mode will be kept until next time cmake is executed.

``` make -j $(nproc)``` 

In case no errors are reported, the generated libraries (if any) will be located at the
_lib_ folder and the executables (if any) will be located at the _bin_ folder.

In order to be able to use the library, it it necessary to copy it into the system.
To do that, execute

``` make install ```

as root and the shared libraries will be copied to */usr/local/lib/iri/battery_monitor* directory
and the header files will be copied to */usr/local/include/iri/battery_monitor* dierctory.
At this point, the library may be used by any user.

To remove the library from the system, exceute

``` make uninstall ```

as root, and all the associated files will be removed from the system.

To generate the documentation execute the following command:

``` make doc ```

### Scripts

It's also needed to run some commands, gathered in this script:

 * Load the *pcspkr* module, so the motherboard buzzers makes sound when alarms are enabled:

   * Persistently, you can run the provided script:

        ```source scripts/load_pcspkr.sh```

   * Or manually once:

        ``` sudo modprobe pcspkr```

## How to use it

To use this library in an other library or application, in the CMakeLists.txt file, first it is necessary to locate if the library has been installed or not using the following command

``` FIND_PACKAGE(battery_monitor) ```

In the case that the package is present, it is necessary to add the header files directory to the include directory path by using

``` INCLUDE_DIRECTORIES(${battery_monitor_INCLUDE_DIRS}) ```

and it is also necessary to link with the desired libraries by using the following command

``` TARGET_LINK_LIBRARIES(<executable name> ${battery_monitor_LIBRARIES}) ```

## Examples

There is one example called _test\_battery\_monitor_, which prints the battery information on the screen.

```./bin/battery_monitor_test```

</p>
</details>
